use sea_orm::entity::prelude::*;
use serde::{Deserialize, Serialize};

#[derive(Debug, Clone, PartialEq, DeriveEntityModel, Serialize, Deserialize)]
#[sea_orm(table_name = "tags")]
pub struct Model {
    #[sea_orm(primary_key)]
    #[serde(skip_deserializing)]
    pub id: u32,
    pub name: String,
}

#[derive(Debug, Clone, Copy, EnumIter)]
pub enum Relation {}

impl RelationTrait for Relation {
    fn def(&self) -> RelationDef {
        panic!()
    }
}

// 没有给标签实体定义关系，而是通过 Related<super::article::Entity>告诉 SeaORM如何去找所需要的文章实体。
impl Related<super::article::Entity> for Entity {
    // 某个实体是否与另一个实体相关
    fn to()-> RelationDef {
        super::article_tag::Relation::Article.def()
    }

    // 某个实体是否通过另一个实体关联 即tag通过article_tag进行关联
    // 表示通过标签实体关联到某个实体的关系，通过 Tag 的反向关系定义进行关联。
    fn via() -> Option<RelationDef> {
        Some(super::article_tag::Relation::Tag.def().rev())
    }
}


impl ActiveModelBehavior for ActiveModel {}



