use sea_orm::{ConnectOptions, Database, DatabaseConnection};
use tracing::{error, info};

use crate::APPLICATION_CONTEXT;
use crate::config::app::AppConfig;

pub async fn init_database() {
    let cfg = APPLICATION_CONTEXT.get::<AppConfig>();

    let mut opt = ConnectOptions::new(&cfg.mysql.dsn);
    opt.max_connections(cfg.mysql.max_cons);

    let sea_orm_conn = Database::connect(opt).await.unwrap();

    sea_orm_conn.ping()
        .await
        .map_err(|e| error!("database init failed: {}", e.to_string()))
        .unwrap();

    APPLICATION_CONTEXT.set::<DatabaseConnection>(sea_orm_conn);

    info!("sea_orm[mysql] database success! {}", &cfg.mysql.dsn);
}