use ::state::type_map::TypeMapSendSync;
use tracing::info;

pub mod state;
pub mod entity;
// pub mod state;
pub mod handler;
pub mod view;
pub mod param;
pub mod form;
pub mod service;
pub mod config;
pub mod router;
pub mod initialize;
pub mod common;


/// 整个项目上下文 ApplicationContext
pub static APPLICATION_CONTEXT: TypeMapSendSync = TypeMapSendSync::new();
// pub static APPLICATION_CONTEXT: TypeMap![Send + Sync] = <TypeMap![Send + Sync]>::new();

pub async fn init_context() {
    // 环境变量初始化 解析 .env 文件
    dotenvy::dotenv().expect("解析.env文件失败");

    // 日志初始化
    initialize::logger::init_trace_logger();

    // 配置文件初始化
    initialize::config::init_config().await;

    info!("ConfigContext init complete");

    // 初始化数据源
    initialize::database::init_database().await;
    info!("DataBase init complete");

    // 冻结 只能使用get 避免额外的开销
    // APPLICATION_CONTEXT.freeze();
}
